@@ -96,8 +96,8 @@ class UDKanbunEntry(UDPipeEntry):
       u[11]=u[9]
       u[15]=u[12]
     if Japanese:
-      import udkanbun.deprelja
-      r=udkanbun.deprelja.deprelja
+      import deplacy.deprelja
+      r=deplacy.deprelja.deprelja
     else:
       r={}
     s=""
@@ -134,7 +134,7 @@ class UDKanbun(object):
         from MeCab import Tagger
       except:
         from fugashi import GenericTagger as Tagger
-      self.mecab=Tagger("-d "+os.path.join(PACKAGE_DIR,"mecab-kanbun"))
+      self.mecab=Tagger("-r "+os.path.join(PACKAGE_DIR,"mecabrc")+" -d "+os.path.join(PACKAGE_DIR,"mecab-kanbun"))
       self.udpipe=ufal.udpipe.Pipeline(m,"conllu","none","","")
     else:
       self.mecab=False
